Products.zms._confmanager.ConfDict

Trees | Indices | Help |
ZMS Python based Content Management System for Science, Technology and Medicine.

Package Products :: Package zms :: Module _confmanager :: Class ConfDict |
[frames] | no frames]

# Class ConfDict

Class Methods
get(cls) |
forName(cls, name) |

Class Variables
| __confdict__ = `None`

Trees | Indices | Help |
ZMS Python based Content Management System for Science, Technology and Medicine.

Generated by Epydoc 3.0.1 on Sat Feb 25 17:30:31 2017 | http://epydoc.sourceforge.net